Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(44)

Unified Diff: tests/compiler/dart2js/compiler_alt.dart

Issue 694353007: Move dart2js from sdk/lib/_internal/compiler to pkg/compiler (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/compiler/dart2js/command_line_split_test.dart ('k') | tests/compiler/dart2js/compiler_helper.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/compiler/dart2js/compiler_alt.dart
diff --git a/tests/compiler/dart2js/compiler_alt.dart b/tests/compiler/dart2js/compiler_alt.dart
index 030e584ae350b67dd2d366de831f707f25cc7336..5296de0802bfa42e8c72cb983282b3bf0731ae71 100644
--- a/tests/compiler/dart2js/compiler_alt.dart
+++ b/tests/compiler/dart2js/compiler_alt.dart
@@ -6,14 +6,14 @@
/// for later inspection.
///
/// Use this in testing to inspect the compiler after compilation by setting
/// the `compileFunc` variable in `package:compiler/implementation/dart2js.dart`
/// to [compiler] before calling the `internalMain` function.
library dart2js.alt;
import 'dart:async';
import 'package:compiler/compiler.dart';
-import 'package:compiler/implementation/apiimpl.dart';
+import 'package:compiler/src/apiimpl.dart';
Compiler compiler;
« no previous file with comments | « tests/compiler/dart2js/command_line_split_test.dart ('k') | tests/compiler/dart2js/compiler_helper.dart » ('j') | no next file with comments »
@@ -6,14 +6,14 @@
///
/// Use this in testing to inspect the compiler after compilation by setting
-/// the `compileFunc` variable in `package:compiler/implementation/dart2js.dart`
+/// the `compileFunc` variable in `package:compiler/src/dart2js.dart`
/// to [compiler] before calling the `internalMain` function.
library dart2js.alt;

Powered by Google App Engine
This is Rietveld 408576698